pub fn ax_tcp_recv(
socket: &AxTcpSocketHandle,
buf: &mut [u8],
) -> AxResult<usize>Expand description
Receives data on the TCP socket, and stores it in the given buffer. On success, returns the number of bytes read.
pub fn ax_tcp_recv(
socket: &AxTcpSocketHandle,
buf: &mut [u8],
) -> AxResult<usize>Receives data on the TCP socket, and stores it in the given buffer. On success, returns the number of bytes read.